@@ -12,9 +12,9 @@ class Task(Orderable):
 
 class SubTask(Orderable):
     """An orderable model with unique_together."""
-    task = models.ForeignKey('Task')
+    task = models.ForeignKey('Task', models.CASCADE)
 
-    class Meta:
+    class Meta(Orderable.Meta):
         unique_together = ('task', 'sort_order')
 
     def __str__(self):
