@@ -1,3 +1,4 @@
+from django.core.exceptions import ValidationError
 from hypothesis import example, given
 from hypothesis.extra.django import TestCase
 from hypothesis.strategies import integers, lists
@@ -188,19 +189,17 @@ class TestSubTask(TestCase):
         """
         task = Task.objects.create()
         subtasks = [
-            SubTask.objects.create(task=task),
-            SubTask.objects.create(task=task),
-            SubTask.objects.create(task=task),
-            SubTask.objects.create(task=task),
+            SubTask.objects.create(task=task, sort_order=3),
+            SubTask.objects.create(task=task, sort_order=4),
+            SubTask.objects.create(task=task, sort_order=1),
+            SubTask.objects.create(task=task, sort_order=2),
         ]
-        subtasks[0].sort_order = 3
-        subtasks[0].save()
-        subtasks[1].sort_order = 4
-        subtasks[1].save()
-        subtasks[2].sort_order = 1
-        subtasks[2].save()
-        subtasks[3].sort_order = 2
-        subtasks[3].save()
+        self.assertSequenceEqual(task.subtask_set.all(), [
+            subtasks[2],
+            subtasks[3],
+            subtasks[0],
+            subtasks[1],
+        ])
 
     def test_changing_parent(self):
         """Check changing the unique together parent."""
@@ -214,6 +213,19 @@ class TestSubTask(TestCase):
         subtask_2.save()
         self.assertSequenceEqual(task.subtask_set.all(), [subtask, subtask_2])
 
+    def test_next_and_prev(self):
+        task = Task.objects.create()
+        task_2 = Task.objects.create()
+        subtask = SubTask.objects.create(task=task)
+        subtask_2 = SubTask.objects.create(task=task)
+        subtask_3 = SubTask.objects.create(task=task_2)
+
+        self.assertEqual(subtask.next(), subtask_2)
+        self.assertIsNone(subtask_2.next())
+
+        self.assertIsNone(subtask_3.prev())
+        self.assertIsNone(subtask_3.next())
+
     @given(lists(integers(min_value=1), min_size=1, unique=True))
     @example([2, 3, 1])
     @example([2, 3, 4])
@@ -226,3 +238,40 @@ class TestSubTask(TestCase):
 
         subtask.sort_order = 2
         subtask.save()
+
+    def test_validate_unique(self):
+        """validate_unique should validate when sort_order conflicts."""
+        task = Task.objects.create()
+        subtask = SubTask.objects.create(task=task, sort_order=1)
+        SubTask.objects.create(task=task, sort_order=2)
+
+        subtask.sort_order = 2
+        try:
+            subtask.validate_unique()
+        except ValidationError:
+            self.fail("SubTask.clean() raised ValidationError unexpectedly!")
+
+    def test_validate_unique_exclude_sort_order(self):
+        """validate_unique should validate when sort_order excluded."""
+        task = Task.objects.create()
+        subtask = SubTask.objects.create(task=task, sort_order=1)
+        SubTask.objects.create(task=task, sort_order=2)
+
+        subtask.sort_order = 2
+        try:
+            subtask.validate_unique(exclude=('sort_order',))
+        except ValidationError:
+            self.fail("SubTask.clean() raised ValidationError unexpectedly!")
+
+    def test_validate_unique_not_unique_sort_order(self):
+        """
+        validate_unique should validate when sort_order not in unique_together.
+        """
+        task = Task.objects.create(sort_order=1)
+        Task.objects.create(sort_order=2)
+
+        task.sort_order = 1
+        try:
+            task.validate_unique()
+        except ValidationError:
+            self.fail("Task.clean() raised ValidationError unexpectedly!")
